<?php

return [
    'Names' => [
        'de' => 'ꄓꇩꉙ',
        'en' => 'ꑱꇩꉙ',
        'es' => 'ꑭꀠꑸꉙ',
        'fr' => 'ꃔꇩꉙ',
        'ii' => 'ꆈꌠꉙ',
        'it' => 'ꑴꄊꆺꉙ',
        'ja' => 'ꏝꀪꉙ',
        'pt' => 'ꁍꄨꑸꉙ',
        'ru' => 'ꊉꇩꉙ',
        'zh' => 'ꍏꇩꉙ',
    ],
    'LocalizedNames' => [
    ],
];
